<?php

use App\Http\Controllers\Book\BookController;
use App\Http\Controllers\Channel\ChannelUserController;
use App\Http\Controllers\Channel\ChannelHomeController;
use App\Http\Controllers\Order\OrderController;
use App\Http\Controllers\Bank\BankController;
use App\Http\Controllers\Settlement\SettlementController;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

// 登录
Route::post('login', [ChannelUserController::class, 'login']);

// 退出登录
Route::get('logout', [ChannelUserController::class, 'logout']);

Route::group(['middleware' => ['bindToken', 'bindExportToken', 'checkLogin']], function () {
    // 重置密码
    Route::post('resetPassword', [ChannelUserController::class, 'resetPassword']);

    // 平台书库
    Route::get('book/list', [BookController::class, 'bookList']);
    Route::get('chapter/list', [BookController::class, 'chapterList']);
    Route::get('chapter/setBookChargeType', [BookController::class, 'setBookChargeType']);
    Route::get('chapter/info', [BookController::class, 'chapterInfo']);
    Route::get('chapter/setSendOrder', [BookController::class, 'setSendOrder']);

    // 投放管理
    Route::get('orderData', [OrderController::class, 'orderData']);                         // 订单明细
    Route::get('userData', [OrderController::class, 'userData']);                           // 用户数据
    Route::get('reportData', [OrderController::class, 'reportData']);                       // 回传日志
    // Route::get('exportReportData', [OrderController::class, 'exportReportData']);           // 回传日志
    Route::get('sendOrderData', [OrderController::class, 'sendOrderData']);                 // 派单列表
    Route::get('sendOrderTemplates', [OrderController::class, 'sendOrderTemplates']);       // 派单适配的充值模板
    Route::post('editSendOrderUrl', [OrderController::class, 'editSendOrderUrl']);          // 编辑派单链接
    Route::get('sendOrderDayData', [OrderController::class, 'sendOrderDayData']);           // 派单日数据
    Route::get('setDayCost', [OrderController::class, 'setDayCost']);                       // 设置派单日数据成本
    Route::get('promotionData', [OrderController::class, 'promotionData']);                 // 推广数据
    Route::get('reportPromotionOrder', [OrderController::class, 'reportPromotionOrder']);   // 补回传

    // 数据统计
    // 站点数据
    Route::get('channelInfo', [ChannelHomeController::class, 'channelInfo']);   // 获取当前站点信息
    Route::get('setChannelBookChargeType', [ChannelHomeController::class, 'setChannelBookChargeType']);   // 设置全站点按本或按章及价格
    Route::get('getSubUser', [ChannelHomeController::class, 'getSubUser']);   // 获取子账号信息
    Route::get('statisticsByTotal', [ChannelHomeController::class, 'statisticsByTotal']);   // 站点总数据
    Route::get('statisticsByDay', [ChannelHomeController::class, 'statisticsByDay']);       // 站点数据按日明细
    Route::get('statisticsByDayForMaster', [ChannelHomeController::class, 'statisticsByDayForMaster']);     // 站点数据推广员按日明细
    Route::get('statisticsByMonthForMaster', [ChannelHomeController::class, 'statisticsByMonthForMaster']);     // 站点数据推广员按月明细
    Route::get('statisticsByMonth', [ChannelHomeController::class, 'statisticsByMonth']);   // 站点数据按月明细
    // 订单列表
    Route::get('order/list', [OrderController::class, 'orderList']);
    // Route::post('order/export', [OrderController::class, 'orderExport']);

    // 运营管理
    Route::get('templateList', [OrderController::class, 'templateList']);                   // 充值模板
    Route::get('setTemplateStatus', [OrderController::class, 'setTemplateStatus']);         // 设置模板是否启用
    Route::post('addTemplate', [OrderController::class, 'addTemplate']);                    // 新增模板
    Route::post('editTemplate', [OrderController::class, 'editTemplate']);                  // 编辑模板


    // 银行卡管理
    Route::get('bank/list', [BankController::class, 'bankList']);                             // 银行下拉列表
    Route::get('channel/bankAccounts', [BankController::class, 'channelBankAccounts']);       // 站点银行卡账号列表
    Route::post('channel/addBankAccount', [BankController::class, 'addBankAccount']);         // 添加银行卡账号
    Route::get('channel/delBankAccount', [BankController::class, 'delBankAccount']);          // 删除银行卡账号
    Route::get('channel/getBankAccountSms', [BankController::class, 'getBankAccountSms']);    // 获取验证码

    // 结算中心
    Route::get('settlement/billsStat', [SettlementController::class, 'billsStat']);           // 结算信息-汇总数据
    Route::get('settlement/bills', [SettlementController::class, 'bills']);                   // 结算信息-列表
    Route::get('settlement/billOrders', [SettlementController::class, 'billOrders']);         // 结算信息-列表-查看明细
    Route::get('settlement/withdrawCashes', [SettlementController::class, 'withdrawCashes']); // 提现信息-列表
    Route::get('settlement/withdraw', [SettlementController::class, 'applyWithDraw']);   // 提现
});

// 用于下载
Route::group(['middleware' => ['bindExportToken', 'checkLogin']], function () {
    // 回传日志导出
    Route::get('exportReportData', [OrderController::class, 'exportReportData']);

    // 订单列表导出
    Route::get('order/export', [OrderController::class, 'orderExport']);

    // 派单数据导出
    Route::get('exportSendOrderData', [OrderController::class, 'exportSendOrderData']);

    // 派单日数据导出
    Route::get('exportSendOrderDayData', [OrderController::class, 'exportSendOrderDayData']);

    // 站点数据按日明细导出
    Route::get('exportStatisticsByDay', [ChannelHomeController::class, 'exportStatisticsByDay']);

    // 站点数据按月明细导出
    Route::get('exportStatisticsByMonth', [ChannelHomeController::class, 'exportStatisticsByMonth']);

    // 站点数据推广员按日明细导出
    Route::get('exportStatisticsByDayForMaster', [ChannelHomeController::class, 'exportStatisticsByDayForMaster']);

    // 站点数据推广员按月明细导出
    Route::get('exportStatisticsByMonthForMaster', [ChannelHomeController::class, 'exportStatisticsByMonthForMaster']);
});
